==> owncloud_7.0.0~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/gl.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "Actualizaronse os axustes.",
"Activity" => "Actividade",
"A file or folder has been <strong>shared</strong>" => "<strong>Compartiuse</strong> un ficheiro ou cartafol",
"A new file or folder has been <strong>created</strong> in a shared folder" => "<strong>Creouse</strong> un novo ficheiro no cartafol compartido",
"A file or folder has been <strong>changed</strong> in a shared folder" => "<strong>Cambiouse</strong> un ficheiro ou cartafol no cartafol compartido",
"A file or folder has been <strong>deleted</strong> from a shared folder" => "<strong>Eliminouse</strong> un ficheiro ou cartafol no cartafol compartido",
"You created %1\$s" => "Creou %1\$s",
"%2\$s created %1\$s" => "%2\$s creado %1\$s",
"You changed %1\$s" => "Cambiou %1\$s",
"%2\$s changed %1\$s" => "%2\$s cambiado %1\$s",
"You deleted %1\$s" => "Eliminou %1\$s",
"%2\$s deleted %1\$s" => "%2\$s eliminado %1\$s",
"You shared %1\$s with %2\$s" => "Compartiu %1\$s con %2\$s",
"You shared %1\$s with group %2\$s" => "Compartiu %1\$s co grupo %2\$s",
"%2\$s shared %1\$s with you" => "%2\$s compartiu %1\$s con vostede",
"You shared %1\$s via link" => "Vostede compartiu %1\$s mediante ligazón",
"Activity notification" => "Notificación da actividade",
"All Activities" => "Todas as actividades",
"Activities by you" => "Actividades súas",
"Activities by others" => "Actividades doutros",
"Shares" => "Comparticións",
"Files" => "Ficheiros",
"%s and %s" => "%s e %s",
", " => ", ",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s e <strong class=\"tooltip\" title=\"%s\">%n máis</strong>","%s e <strong class=\"tooltip\" title=\"%s\">%n máis</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s e %n máis","%s e %n máis"),
"Hello %s," => "Ola %s,",
"You are receiving this email because in the last hour the following things happened at %s" => "Recibe este correo porque na última hora sucederon as seguintes cousas en %s",
"You are receiving this email because in the last day the following things happened at %s" => "Recibe este correo porque no último día sucederon as seguintes cousas en %s",
"You are receiving this email because in the last week the following things happened at %s" => "Recibe este correo porque na última semana sucederon as seguintes cousas en %s",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "Verá una lista de accións cando se comece a utilizar o seu %s.",
"No more events to load" => "Non hai máis actividades para cargar",
"Enable RSS feed" => "Activar as fontes RSS",
"Notifications" => "Notificacións",
"Mail" => "Correo",
"Stream" => "Fluxo",
"You need to set up your email address before you can receive notification emails." => "É necesario estabelecer o enderezo correo para poder recibir correos de notificación.",
"Send emails:" => "Enviar os correos:",
"Hourly" => "Cada hora",
"Daily" => "A diario",
"Weekly" => "Semanalmente",
"Activity feed" => "Fonte da actividade",
"Personal activity feed for %s" => "Fonte da actividade persoal para %s"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> owncloud_7.0.1~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/gl.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "Actualizaronse os axustes.",
"Activity" => "Actividade",
"A file or folder has been <strong>shared</strong>" => "<strong>Compartiuse</strong> un ficheiro ou cartafol",
"A new file or folder has been <strong>created</strong>" => "<strong>Creouse</strong> un novo ficheiro ou cartafol",
"A file or folder has been <strong>changed</strong>" => "<strong>Cambiouse</strong> un ficheiro ou cartafol",
"A file or folder has been <strong>deleted</strong>" => "<strong>Eliminouse</strong> un ficheiro ou cartafol",
"You created %1\$s" => "Creou %1\$s",
"%2\$s created %1\$s" => "%2\$s creado %1\$s",
"You changed %1\$s" => "Cambiou %1\$s",
"%2\$s changed %1\$s" => "%2\$s cambiado %1\$s",
"You deleted %1\$s" => "Eliminou %1\$s",
"%2\$s deleted %1\$s" => "%2\$s eliminado %1\$s",
"You shared %1\$s with %2\$s" => "Compartiu %1\$s con %2\$s",
"You shared %1\$s with group %2\$s" => "Compartiu %1\$s co grupo %2\$s",
"%2\$s shared %1\$s with you" => "%2\$s compartiu %1\$s con vostede",
"You shared %1\$s via link" => "Vostede compartiu %1\$s mediante ligazón",
"Activity notification" => "Notificación da actividade",
"All Activities" => "Todas as actividades",
"Activities by you" => "Actividades súas",
"Activities by others" => "Actividades doutros",
"Shares" => "Comparticións",
"Files" => "Ficheiros",
"%s and %s" => "%s e %s",
", " => ", ",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s e <strong class=\"tooltip\" title=\"%s\">%n máis</strong>","%s e <strong class=\"tooltip\" title=\"%s\">%n máis</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s e %n máis","%s e %n máis"),
"Hello %s," => "Ola %s,",
"You are receiving this email because in the last hour the following things happened at %s" => "Recibe este correo porque na última hora sucederon as seguintes cousas en %s",
"You are receiving this email because in the last day the following things happened at %s" => "Recibe este correo porque no último día sucederon as seguintes cousas en %s",
"You are receiving this email because in the last week the following things happened at %s" => "Recibe este correo porque na última semana sucederon as seguintes cousas en %s",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "Verá una lista de accións cando se comece a utilizar o seu %s.",
"No more events to load" => "Non hai máis actividades para cargar",
"Enable RSS feed" => "Activar as fontes RSS",
"Notifications" => "Notificacións",
"Mail" => "Correo",
"Stream" => "Fluxo",
"Notify about my own actions" => "Notificarme as miñas propias accións",
"You need to set up your email address before you can receive notification emails." => "É necesario estabelecer o enderezo correo para poder recibir correos de notificación.",
"Send emails:" => "Enviar os correos:",
"Hourly" => "Cada hora",
"Daily" => "A diario",
"Weekly" => "Semanalmente",
"Activity feed" => "Fonte da actividade",
"Personal activity feed for %s" => "Fonte da actividade persoal para %s"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
